@@ -110,7 +110,11 @@ def draw_all_box_and_label_pil(img, boxes, outline='red', width=2, text_color='w
         x1 = max(box[0], 0)
         y1 = max(box[1] - text_size - 3, 0)
         point = (x1, y1)
-        draw.rectangle((x1, y1, x1 + text_size * len(label) / 2 + 24, y1 + text_size), fill=text_bg_color)
+        try:
+            text_width = len(label.encode('gb2312'))
+        except:
+            text_width = len(label)
+        draw.rectangle((x1, y1, x1 + text_size * text_width / 2, y1 + text_size), fill=text_bg_color)
         draw.text(point, label, text_color, font=font)  # 参数1：打印坐标，参数2：文本，参数3：字体颜色，参数4：字体
 
     return img
